@@ -561,9 +561,22 @@ class CensiusClient(object):
             registered_dataset_details = json.loads(response.content)
             registered_dataset_to_datatype, registered_model_target = dict(), list()
             registered_dataset_to_datatype = registered_dataset_details["dataset_datatype"]
+            registered_model_target_to_datatype = registered_dataset_details[
+                "model_target_datatype"
+            ]
             registered_model_target = registered_dataset_details["model_target"]
             model_target_col = registered_model_target[0]
 
+            # merge registered_model_target_to_datatype with registered_dataset_to_datatype
+            """
+            registered_dataset_to_datatype = {"Age": "integer","Pclass": "integer"}
+            registered_model_target_to_datatype = {"Survived": "integer"} # then
+            registered_dataset_to_datatype = {"Age": "integer",
+                                           "Pclass": "integer",
+                                           "Survived": "integer"}
+            """
+            registered_dataset_to_datatype.update(registered_model_target_to_datatype)
+
             # remove model_target from registered_dataset_to_datatype
         else:
             return self.__return_message(response)
@@ -850,7 +863,6 @@ class CensiusClient(object):
             }
         )
         headers = {"Authorization": "Bearer " + self.api_key, "Content-Type": "application/json"}
-
         response = requests.request("POST", LOG_EXPLAINATIONS_URL(), headers=headers, data=payload)
         return self.__return_message(response)
 
