@@ -331,6 +331,7 @@ class BulkLogProcessing:
     def __init__(self):
         self.bulk_log_post_url = BULK_LOG_URL
         self.bulk_explain_post_url = BULK_EXPLAINATIONS_URL
+        self.bulk_chunk_size = BULK_CHUNK_SIZE
         self.bulk_log_data_key = "bulk_logs"
         self.bulk_explain_data_key = "bulk_explainations"
         self.insertion_wait_time = 15
@@ -350,8 +351,8 @@ class BulkLogProcessing:
     ) -> dict:
         # len of dataframe is greater than 10,000 divide into chunks of 10,000
         bulkID = self._generate_bulk_log_id_()
-        if len(dataframe) > 10000:
-            dataframe_chunks = np.array_split(dataframe, len(dataframe) / 10000)
+        if len(dataframe) > self.bulk_chunk_size:
+            dataframe_chunks = np.array_split(dataframe, len(dataframe) / self.bulk_chunk_size)
             totalChunk = len(dataframe_chunks)
             for index, chunk in enumerate(dataframe_chunks):
                 bulk_log_details = {
